@@ -783,6 +783,6 @@ def edges(graph):
         for par in parents(graph, var):
             edge.loc[len(edge)] = [par, var, 'directed']
         for nei in graph[var]['nei']:
-            if len(edge[edge['from'] == nei and edge['to'] == var]) == 0:
+            if len(edge[(edge['from'] == nei) & (edge['to'] == var)]) == 0:
                 edge.loc[len(edge)] = [var, nei, 'undirected']
     return edge
\ No newline at end of file
