@@ -64,7 +64,7 @@ def check_cycle(vi, vj, dag):
     return cyc_flag
 
 
-def hc(data, method='standard', score_function='default', debug=False, alpha=0.3):
+def hc(data, method='standard', score='default', debug=False, alpha=0.3):
     '''
         :param data: the training data used for learn BN
         :param method: the method for dealing with missing values, including:
@@ -73,22 +73,22 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                        ipw (inverse probability weighting)
                        aipw (adaptive ipw)
                        standard (standard HC)
-        :param score_function: score function, including:
+        :param score: score function, including:
                        bic (Bayesian Information Criterion for discrete variable)
                        nal (Node Average Likelihood for discrete variable)
         :return: the learned BN
     '''
-    if score_function == 'default':
+    if score == 'default':
         if all(data[var].dtype.name == 'category' for var in data):
-            score_function = 'bic'
+            score = 'bic'
         elif all(data[var].dtype.name != 'category' for var in data):
-            score_function = 'bic_g'
+            score = 'bic_g'
         else:
             raise Exception('Mixed type of data is not supported yet.')
     data, dc = pre_process(data)
     if method == 'lw':
         data_listwise = data.dropna()
-        dag = hc(data_listwise, score_function=score_function, debug=debug)
+        dag = hc(data_listwise, score=score, debug=debug)
     elif method == 'pw' or method == 'ipw' or method == 'aipw':
         # calculate the run time
         time_total = time.time()
@@ -152,7 +152,7 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                             cache_score[vj][par_cur] = {}
                         if W not in cache_score[vj][par_cur]:
                             cols = [varnames.index(vj)] + [varnames.index(x) for x in varnames if x in par_cur]
-                            cache_score[vj][par_cur][W] = local_score(cache_data[W], cols, score_function,
+                            cache_score[vj][par_cur][W] = local_score(cache_data[W], cols, score,
                                                                       cache_weight[W])
                         # compute the local score for the searching graph
                         par_sea = tuple(sorted(dag[vj]['par'] + [vi]))
@@ -160,7 +160,7 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                             cache_score[vj][par_sea] = {}
                         if W not in cache_score[vj][par_sea]:
                             cols = [varnames.index(vj)] + [varnames.index(x) for x in varnames if x in par_sea]
-                            cache_score[vj][par_sea][W] = local_score(cache_data[W], cols, score_function,
+                            cache_score[vj][par_sea][W] = local_score(cache_data[W], cols, score,
                                                                       cache_weight[W])
                         if cache_score[vj][par_sea][W] != np.nan:
                             diff_temp = cache_score[vj][par_sea][W] - cache_score[vj][par_cur][W]
@@ -199,14 +199,14 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                         if W not in cache_score[par_vi][par_cur_par_vi]:
                             cols = [varnames.index(par_vi)] + [varnames.index(x) for x in varnames if
                                                                x in par_cur_par_vi]
-                            cache_score[par_vi][par_cur_par_vi][W] = local_score(cache_data[W], cols, score_function,
+                            cache_score[par_vi][par_cur_par_vi][W] = local_score(cache_data[W], cols, score,
                                                                                  cache_weight[W])
                         par_cur_vi = tuple(dag[vi]['par'])
                         if par_cur_vi not in cache_score[vi]:
                             cache_score[vi][par_cur_vi] = {}
                         if W not in cache_score[vi][par_cur_vi]:
                             cols = [varnames.index(vi)] + [varnames.index(x) for x in varnames if x in par_cur_vi]
-                            cache_score[vi][par_cur_vi][W] = local_score(cache_data[W], cols, score_function,
+                            cache_score[vi][par_cur_vi][W] = local_score(cache_data[W], cols, score,
                                                                          cache_weight[W])
                         # compute the local score for the searching graph
                         par_sea_par_vi = tuple(sorted(dag[par_vi]['par'] + [vi]))
@@ -216,13 +216,13 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                             cols = [varnames.index(par_vi)] + [varnames.index(x) for x in varnames if
                                                                x in par_sea_par_vi]
                             cache_score[par_vi][par_sea_par_vi][W] = local_score(cache_data[W], cols,
-                                                                                 score_function, cache_weight[W])
+                                                                                 score, cache_weight[W])
                         par_sea_vi = tuple([x for x in dag[vi]['par'] if x != par_vi])
                         if par_sea_vi not in cache_score[vi]:
                             cache_score[vi][par_sea_vi] = {}
                         if W not in cache_score[vi][par_sea_vi]:
                             cols = [varnames.index(vi)] + [varnames.index(x) for x in varnames if x in par_sea_vi]
-                            cache_score[vi][par_sea_vi][W] = local_score(cache_data[W], cols, score_function,
+                            cache_score[vi][par_sea_vi][W] = local_score(cache_data[W], cols, score,
                                                                          cache_weight[W])
                         if cache_score[vi][par_cur_vi][W] != np.nan and cache_score[par_vi][par_sea_par_vi][
                             W] != np.nan:
@@ -255,7 +255,7 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                             cache_score[vi][par_cur] = {}
                         if W not in cache_score[vi][par_cur]:
                             cols = [varnames.index(vi)] + [varnames.index(x) for x in varnames if x in par_cur]
-                            cache_score[vi][par_cur][W] = local_score(cache_data[W], cols, score_function,
+                            cache_score[vi][par_cur][W] = local_score(cache_data[W], cols, score,
                                                                       cache_weight[W])
                         # compute the local score for the searching graph
                         par_sea = tuple([x for x in dag[vi]['par'] if x != par_vi])
@@ -263,7 +263,7 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                             cache_score[vi][par_sea] = {}
                         if W not in cache_score[vi][par_sea]:
                             cols = [varnames.index(vi)] + [varnames.index(x) for x in varnames if x in par_sea]
-                            cache_score[vi][par_sea][W] = local_score(cache_data[W], cols, score_function,
+                            cache_score[vi][par_sea][W] = local_score(cache_data[W], cols, score,
                                                                       cache_weight[W])
                         if cache_score[vi][par_cur][W] != np.nan:
                             diff_temp = cache_score[vi][par_sea][W] - cache_score[vi][par_cur][W]
@@ -302,7 +302,7 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
             raise Exception('Mixed data is not supported.')
         # initialise dag, cached scores and candidate parents for each variable
         dag = {var: {'par': [], 'nei': []} for var in varnames}
-        cache = {var: {tuple([]): local_score(data, [varnames.index(var)], score_function, alpha=alpha)} for var in
+        cache = {var: {tuple([]): local_score(data, [varnames.index(var)], score, alpha=alpha)} for var in
                  varnames}
         candidate = {var: [v for v in varnames if v is not var] for var in varnames}
         time_preprocess = time.time() - start_time
@@ -323,7 +323,7 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                         par_sea = tuple(sorted(dag[vj]['par'] + [vi]))
                         if par_sea not in cache[vj]:
                             cols = [varnames.index(x) for x in (vj,) + par_sea]
-                            cache[vj][par_sea] = local_score(data, cols, score_function, alpha=alpha)
+                            cache[vj][par_sea] = local_score(data, cols, score, alpha=alpha)
                         time_score += time.time() - start_time
                         diff_temp = cache[vj][par_sea] - cache[vj][tuple(dag[vj]['par'])]
                         if debug:
@@ -343,11 +343,11 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                         par_sea_par_vi = tuple(sorted(dag[par_vi]['par'] + [vi]))
                         if par_sea_par_vi not in cache[par_vi]:
                             cols = [varnames.index(x) for x in (par_vi,) + par_sea_par_vi]
-                            cache[par_vi][par_sea_par_vi] = local_score(data, cols, score_function, alpha=alpha)
+                            cache[par_vi][par_sea_par_vi] = local_score(data, cols, score, alpha=alpha)
                         par_sea_vi = tuple([x for x in dag[vi]['par'] if x != par_vi])
                         if par_sea_vi not in cache[vi]:
                             cols = [varnames.index(x) for x in (vi,) + par_sea_vi]
-                            cache[vi][par_sea_vi] = local_score(data, cols, score_function, alpha=alpha)
+                            cache[vi][par_sea_vi] = local_score(data, cols, score, alpha=alpha)
                         time_score += time.time() - start_time
                         diff_temp = cache[par_vi][par_sea_par_vi] + cache[vi][par_sea_vi] - cache[par_vi][
                             tuple(dag[par_vi]['par'])] - cache[vi][tuple(dag[vi]['par'])]
@@ -363,7 +363,7 @@ def hc(data, method='standard', score_function='default', debug=False, alpha=0.3
                     par_sea = tuple([x for x in dag[vi]['par'] if x != par_vi])
                     if par_sea not in cache[vi]:
                         cols = [varnames.index(x) for x in (vi,) + par_sea]
-                        cache[vi][par_sea] = local_score(data, cols, score_function, alpha=alpha)
+                        cache[vi][par_sea] = local_score(data, cols, score, alpha=alpha)
                     time_score += time.time() - start_time
                     diff_temp = cache[vi][par_sea] - cache[vi][tuple(dag[vi]['par'])]
                     if diff_temp - diff > 1e-10:
@@ -562,7 +562,7 @@ def pc_stable(data, test='default', threshold=0.05, debug=False):
 #     return post_process(dag, dc)
 
 
-def ges(data, method='complete', score_function='default', prune=True, thres=0.1, alpha=0.3, debug=False):
+def ges(data, method='complete', score='default', prune=True, thres=0.1, alpha=0.3, debug=False):
     '''
     greedy equivalence search algorithm
     :param data: the training data used for learn BN
@@ -572,7 +572,7 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
                    ipw (inverse probability weighting)
                    aipw (adaptive ipw)
                    complete (regular)
-    :param score_function: score function, including:
+    :param score: score function, including:
                    bic (Bayesian Information Criterion for discrete variable)
                    bic_g (Bayesian Information Criterion for continuous variable)
                    nal (Node Average Likelihood for discrete variable)
@@ -592,15 +592,15 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
         if all(data[var].dtype.name == 'category' for var in data):
             datatype = 'category'
             data = data.apply(lambda x: x.cat.codes).to_numpy()
-            if score_function == 'default':
-                score_function = 'bic'
+            if score == 'default':
+                score = 'bic'
         elif all(data[var].dtype.name != 'category' for var in data):
             datatype = 'continuous'
             data = data.to_numpy()
-            if score_function == 'default' or score_function == 'bic':
-                score_function = 'bic_g'
-            elif score_function == 'nal':
-                score_function = 'nal_g'
+            if score == 'default' or score == 'bic':
+                score = 'bic_g'
+            elif score == 'nal':
+                score = 'nal_g'
         else:
             raise Exception('Mixed data is not supported.')
         cache = {var: {} for var in varnames}
@@ -634,11 +634,11 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
 
                             if parents_new not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_new]
-                                cache[y][parents_new] = local_score(data, cols, score_function, alpha=alpha)
+                                cache[y][parents_new] = local_score(data, cols, score, alpha=alpha)
                             score_new = cache[y][parents_new]
                             if parents_cur not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_cur]
-                                cache[y][parents_cur] = local_score(data, cols, score_function, alpha=alpha)
+                                cache[y][parents_cur] = local_score(data, cols, score, alpha=alpha)
                             score_cur = cache[y][parents_cur]
                             diff_temp = score_new - score_cur
                             if diff_temp > diff:
@@ -681,11 +681,11 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
 
                             if parents_new not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_new]
-                                cache[y][parents_new] = local_score(data, cols, score_function, alpha=alpha)
+                                cache[y][parents_new] = local_score(data, cols, score, alpha=alpha)
                             score_new = cache[y][parents_new]
                             if parents_cur not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_cur]
-                                cache[y][parents_cur] = local_score(data, cols, score_function, alpha=alpha)
+                                cache[y][parents_cur] = local_score(data, cols, score, alpha=alpha)
                             score_cur = cache[y][parents_cur]
                             diff_temp = score_new - score_cur
                             if diff_temp > diff:
@@ -716,15 +716,15 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
         if all(data[var].dtype.name == 'category' for var in data):
             datatype = 'category'
             data = data.apply(lambda x: x.cat.codes).to_numpy()
-            if score_function == 'default':
-                score_function = 'bic'
+            if score == 'default':
+                score = 'bic'
         elif all(data[var].dtype.name != 'category' for var in data):
             datatype = 'continuous'
             data = data.to_numpy()
-            if score_function == 'default' or score_function == 'bic':
-                score_function = 'bic_g'
-            elif score_function == 'nal':
-                score_function = 'nal_g'
+            if score == 'default' or score == 'bic':
+                score = 'bic_g'
+            elif score == 'nal':
+                score = 'nal_g'
         else:
             raise Exception('Mixed data is not supported.')
         # initialize the candidate nodes for each variable to be connected with
@@ -765,13 +765,13 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
                                 cache_score[y][W] = {}
                             if parents_new not in cache_score[y][W]:
                                 cols = [varnames.index(v) for v in (y,) + parents_new]
-                                cache_score[y][W][parents_new] = local_score(cache_data[W], cols, score_function,
+                                cache_score[y][W][parents_new] = local_score(cache_data[W], cols, score,
                                                                              weights=cache_weights[W])
                             score_new = cache_score[y][W][parents_new]
 
                             if parents_cur not in cache_score[y][W]:
                                 cols = [varnames.index(v) for v in (y,) + parents_cur]
-                                cache_score[y][W][parents_cur] = local_score(cache_data[W], cols, score_function,
+                                cache_score[y][W][parents_cur] = local_score(cache_data[W], cols, score,
                                                                              weights=cache_weights[W])
                             score_cur = cache_score[y][W][parents_cur]
                             diff_temp = score_new - score_cur
@@ -819,12 +819,12 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
                                 cache_score[y][W] = {}
                             if parents_new not in cache_score[y][W]:
                                 cols = [varnames.index(v) for v in (y,) + parents_new]
-                                cache_score[y][W][parents_new] = local_score(cache_data[W], cols, score_function,
+                                cache_score[y][W][parents_new] = local_score(cache_data[W], cols, score,
                                                                              weights=cache_weights[W])
                             score_new = cache_score[y][W][parents_new]
                             if parents_cur not in cache_score[y][W]:
                                 cols = [varnames.index(v) for v in (y,) + parents_cur]
-                                cache_score[y][W][parents_cur] = local_score(cache_data[W], cols, score_function,
+                                cache_score[y][W][parents_cur] = local_score(cache_data[W], cols, score,
                                                                              weights=cache_weights[W])
                             score_cur = cache_score[y][W][parents_cur]
                             diff_temp = score_new - score_cur
